@@ -8,7 +8,7 @@
 ### AUTHORS:  Mathieu Pigeon, Vincent Goulet <vincent.goulet@act.ulaval.ca>
 
 mlnorm <- function(order, meanlog = 0, sdlog = 1)
-    .External("do_dpq", "mlnorm", order, meanlog, sdlog, FALSE)
+    .External("actuar_do_dpq", "mlnorm", order, meanlog, sdlog, FALSE)
 
 levlnorm <- function(limit, meanlog = 0, sdlog = 1, order = 1)
-    .External("do_dpq", "levlnorm", limit, meanlog, sdlog, order, FALSE)
+    .External("actuar_do_dpq", "levlnorm", limit, meanlog, sdlog, order, FALSE)
